#ifndef NT2_INCLUDE_FUNCTIONS_MODF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MODF_HPP_INCLUDED

#include <nt2/ieee/include/functions/modf.hpp>

#endif
